Header menu logo Fabulous.AST

AbstractMemberModifiers Type

Static members

Static member Description

AbstractMemberModifiers.attribute (this, attribute)

Full Usage: AbstractMemberModifiers.attribute (this, attribute)

Parameters:
Returns: WidgetBuilder<MemberDefn>

Sets the attribute for the current member definition widget.

this : WidgetBuilder<MemberDefn>

Current widget.

attribute : WidgetBuilder<AttributeNode>

The attribute to set.

Returns: WidgetBuilder<MemberDefn>

AbstractMemberModifiers.attributes (this, attributes)

Full Usage: AbstractMemberModifiers.attributes (this, attributes)

Parameters:
Returns: WidgetBuilder<MemberDefn>

Sets the attributes for the current member definition widget.

this : WidgetBuilder<MemberDefn>

Current widget.

attributes : WidgetBuilder<AttributeNode> seq

The attributes to set.

Returns: WidgetBuilder<MemberDefn>

AbstractMemberModifiers.toStatic this

Full Usage: AbstractMemberModifiers.toStatic this

Parameters:
Returns: WidgetBuilder<MemberDefn>

Sets the current member definition widget to be static.

this : WidgetBuilder<MemberDefn>

Current widget.

Returns: WidgetBuilder<MemberDefn>

AbstractMemberModifiers.xmlDocs (this, xmlDocs)

Full Usage: AbstractMemberModifiers.xmlDocs (this, xmlDocs)

Parameters:
Returns: WidgetBuilder<MemberDefn>

Sets the XmlDocs for the current member.

this : WidgetBuilder<MemberDefn>

Current widget.

xmlDocs : string seq

The XmlDocs to set.

Returns: WidgetBuilder<MemberDefn>

AbstractMemberModifiers.xmlDocs (this, xmlDocs)

Full Usage: AbstractMemberModifiers.xmlDocs (this, xmlDocs)

Parameters:
Returns: WidgetBuilder<MemberDefn>

Sets the XmlDocs for the current member.

this : WidgetBuilder<MemberDefn>

Current widget.

xmlDocs : WidgetBuilder<XmlDocNode>

The XmlDocs to set.

Returns: WidgetBuilder<MemberDefn>

Type something to start searching.